class Browser {
  constructor(tracker) {
    this.tracker = tracker;
    this.userAgent = this.getUserAgent();
    this.isMobile = this.detectMobile();
    this.browserName = this.detectBrowser();
    this.order = 'before';
    return this;
  }

  /** @returns string */
  getUserAgent() {
    return (typeof navigator !== 'undefined' && navigator.userAgent) ? navigator.userAgent : '';
  }

  /** @returns boolean */
  detectMobile() {
    let isMobile = false;
    if (/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|ipad|iris|kindle|Android|Silk|lge |maemo|midp|mmp|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i.test(this.getUserAgent())) {
      isMobile = true;
    }
    return isMobile;
  }

  /** @returns string */
  detectBrowser() {
    const ua = this.getUserAgent();
    let tem; // FIXME: make this code more readable
    let M = ua.match(/(opera|chrome|safari|firefox|msie|trident(?=\/))\/?\s*(\d+)/i) || [];
    if (/trident/i.test(M[1])) {
      tem = /\brv[ :]+(\d+)/g.exec(ua) || [];
      if (tem && tem.length > 0) return `IE ${(tem[1] || '')}`;
    }
    if (M[1] === 'Chrome') {
      tem = ua.match(/\b(OPR|Edge)\/(\d+)/);
      if (tem && tem.length > 0) return tem.slice(1).join(' ').replace('OPR', 'Opera');
    }
    M = M[2] ? [M[1], M[2]] : [navigator.appName, navigator.appVersion, '-?'];
    if (tem && tem.length > 0 && (ua.match(/version\/(\d+)/i)) != null) M.splice(1, 1, tem[1]);
    return M.join(' ');
  }

  getBrowser() {
    let browser = {};
    if (navigator) {
      browser = {
        appName: navigator.appName,
        userAgent: this.userAgent,
        isMobile: this.isMobile,
        language: navigator.language,
        platform: navigator.platform,
        browserName: this.browserName,
      };
    }

    return browser;
  }

  callback(event) {
    event.data.browser = this.getBrowser();
    return event;
  }
}

export default Browser;
