/* global __dirname, require, module*/

const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const UglifyJsPlugin = webpack.optimize.UglifyJsPlugin;
const path = require('path');
const env = require('yargs').argv.env; // use --env with webpack 2

let libraryName = 'snoopy';

let plugins = [], outputFile;

if (env === 'build') {
  plugins.push(new UglifyJsPlugin({ minimize: true }));
  outputFile = libraryName + '.min.js';
} else {
  plugins.push(new HtmlWebpackPlugin());
  outputFile = libraryName + '.js';
}

const config = {
  entry: __dirname + '/src/snoopy.js',
  devtool: 'source-map',
  target: 'web',
  output: {
    path: __dirname + '/lib',
    filename: outputFile,
    library: libraryName,
    libraryTarget: 'umd',
    umdNamedDefine: true
  },
  module: {
    rules: [
      {
        test: /(\.jsx|\.js)$/,
        use: {
          loader: 'babel-loader',
          options: {
            presets: ['es2015'],
            plugins: ['import-glob']
          }
        },
        exclude: /(node_modules|bower_components)/
      },
      {
        test: /(\.jsx|\.js)$/,
        loader: 'eslint-loader',
        exclude: /node_modules/
      }
    ]
  },
  resolve: {
    modules: [path.resolve('./node_modules'), path.resolve('./src'), path.resolve('./src/plugins')],
    extensions: ['.json', '.js']
  },
  plugins: plugins,
  devServer: {
    contentBase: path.join(__dirname, "dist"),
    compress: true,
    port: 9235,
    watchContentBase: true
  }
};

module.exports = config;
